<?php


namespace Service;


use Doctrine\ORM\EntityManager;
use Exception;
use Service\Integration\IntegrationSM;
use Teknisa\Libs\Util\Masks\Picture;
use Teknisa\Model\Teknisa\Entities\CpCall;
use Teknisa\Model\Teknisa\Entities\Orcasolicita;
use Teknisa\Model\Teknisa\Entities\Parcsoliserv;
use Teknisa\Model\Teknisa\Entities\Tarefa;
use Util\Instance\Repository;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\DevOps\Model\Projectmanagement\Entities\Resource;
use Zeedhi\DevOps\Util\Utilities as DevOpsUtilities;
use Zeedhi\Framework\ORM\DateTime;
use Zeedhi\DevOps\Model\Projectmanagement\Entities;
use Zeedhi\DevOps\Model\Projectmanagement\Repositories;
use Util\Messages;

class IssueLabels
{
    /**
     * @var EntityManager
     */
    public $entityManager;
    /**
     * @var Utilities
     */
    public $environment;

    /**
     * @var int|mixed
     */
    private $nrorg;

    public function __construct()
    {
        $this->entityManager  = InstanceProvider::getEntityManager();
        $this->environment    = InstanceProvider::getEnvironment();

        $this->nrorg = $this->environment->getCurrentOrganizationId();
    }

    public function findMyIssueLabels()
    {
        $findMyIssueLabels = InstanceProvider::getRepository()->getIssueLabelsLocal();
        return $findMyIssueLabels->findMyIssueLabels($this->environment->getCurrentUserId());
    }

    public function findProjectProductAndMeeting()
    {
        $userId = $this->environment->getCurrentUserId();
        $organizationId = $this->environment->getCurrentOrganizationId();
        $products = InstanceProvider::getRepository()->getIssueLabelsLocal()->findProjectProductAndMeeting($userId);
        $products['data'] = DevOpsUtilities::removeModels($products['data'], $organizationId);
        return $products;
    }

    public function saveIssueLabels($issueLabel, $description, $project)
    {
        $connection = $this->entityManager->getConnection();
		try {
			$connection->beginTransaction();
			if(empty($project)){
				$resource = $this->environment->getCurrentUser();
			}
			else{
				$project = $this->entityManager->find('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Project', $project);
				$resource = null;
			}
            $labelFactory = InstanceProvider::getFactory()->getIssueLabels();
			if(empty($issueLabel)){
				$issueLabel = $labelFactory->createLabel($description, $project, $resource);
			}
			else{
				$issueLabel = $labelFactory
					->updateLabel(	$this->entityManager->find('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Label', $issueLabel), $description,
						$project, $resource);
			}
			$this->entityManager->persist($issueLabel);
			$this->entityManager->flush();
			$connection->commit();
		} catch (\Exception $e) {
            try {
                $connection->rollBack();
            } catch (\Exception $e2) {
            }
            throw $e;
		}
    }

    public function removeIssueLabels($rows)
    {
        $connection = $this->entityManager->getConnection();
		try {
			$connection->beginTransaction();
            foreach($rows as $row) {
                $taskLabels = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\TaskLabel')
				->findBy(array('label' => $row['ID']));
                foreach ($taskLabels as $taskLabel) {
                    $this->entityManager->remove($taskLabel);
                }
                $this->entityManager->remove($this->entityManager->find('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Label', $row['ID']));
                $this->entityManager->flush();
            }
			$connection->commit();
		} catch (\Exception $e) {
			$connection->rollBack();
			throw $e;
		}
    }

    public function saveDescricaoGrid($rows)
    {
        foreach($rows as $row) {
            $this->saveIssueLabels($row['ID'], $row['DESCRIPTION'], $row['PROJECT']);
        }
    }
}
